@@ -599,7 +599,7 @@ size_t snd_pcm_access_mask_sizeof(void)
 static inline
 int snd_pcm_access_mask_malloc(snd_pcm_access_mask_t **ptr)
 {
-	*ptr = calloc(1, sizeof(*ptr));
+	*ptr = calloc(1, sizeof(**ptr));
 	if (!*ptr)
 		return -ENOMEM;
 	return 0;
@@ -663,7 +663,7 @@ size_t snd_pcm_format_mask_sizeof(void)
 static inline
 int snd_pcm_format_mask_malloc(snd_pcm_format_mask_t **ptr)
 {
-	*ptr = calloc(1, sizeof(*ptr));
+	*ptr = calloc(1, sizeof(**ptr));
 	if (!*ptr)
 		return -ENOMEM;
 	return 0;
@@ -727,7 +727,7 @@ size_t snd_pcm_subformat_mask_sizeof(void)
 static inline
 int snd_pcm_subformat_mask_malloc(snd_pcm_subformat_mask_t **ptr)
 {
-	*ptr = calloc(1, sizeof(*ptr));
+	*ptr = calloc(1, sizeof(**ptr));
 	if (!*ptr)
 		return -ENOMEM;
 	return 0;
@@ -795,7 +795,7 @@ size_t snd_pcm_hw_params_sizeof(void)
 static inline
 int snd_pcm_hw_params_malloc(snd_pcm_hw_params_t **ptr)
 {
-	*ptr = calloc(1, sizeof(*ptr));
+	*ptr = calloc(1, sizeof(**ptr));
 	if (!*ptr)
 		return -ENOMEM;
 	return 0;
@@ -1770,7 +1770,7 @@ size_t snd_pcm_sw_params_sizeof(void)
 static inline
 int snd_pcm_sw_params_malloc(snd_pcm_sw_params_t **ptr)
 {
-	*ptr = calloc(1, sizeof(*ptr));
+	*ptr = calloc(1, sizeof(**ptr));
 	if (!*ptr)
 		return -ENOMEM;
 	return 0;
@@ -1940,7 +1940,7 @@ size_t snd_pcm_status_sizeof(void)
 static inline
 int snd_pcm_status_malloc(snd_pcm_status_t **ptr)
 {
-	*ptr = calloc(1, sizeof(*ptr));
+	*ptr = calloc(1, sizeof(**ptr));
 	if (!*ptr)
 		return -ENOMEM;
 	return 0;
@@ -2025,7 +2025,7 @@ size_t snd_pcm_info_sizeof(void)
 static inline
 int snd_pcm_info_malloc(snd_pcm_info_t **ptr)
 {
-	*ptr = calloc(1, sizeof(*ptr));
+	*ptr = calloc(1, sizeof(**ptr));
 	if (!*ptr)
 		return -ENOMEM;
 	return 0;
